@@ -1,26 +1,36 @@
-#' Create a ggplot object from an `utsf` object
+#' Create a ggplot object from an `utsf_forecast` object
 #'
 #' Plot the time series and its associated forecast.
 #'
-#' @param object An object of class `utsf`.
+#' @param object An object of class `utsf_forecast`.
 #' @param ... additional parameter.
 #'
 #' @return The `ggplot` object representing a plotting of the time series and
 #'   its forecast.
 #'
 #' @examples
-#' f <- forecast(AirPassengers, h = 12, lags = 1:12, method = "rf")
+#' m <- create_model(AirPassengers, lags = 1:12, method = "rf")
+#' f <- forecast(m, h = 12)
 #' library(ggplot2)
 #' autoplot(f)
 #' @export
 #' @importFrom ggplot2 autoplot
-autoplot.utsf <- function(object, ...) {
-  vctsfr::plot_ts(object$ts, prediction = object$pred)
+autoplot.utsf_forecast <- function(object, ...) {
+  if (is.null(object$lower)) {
+    vctsfr::plot_ts(object$ts, prediction = object$pred)
+  } else {
+    vctsfr::plot_ts(object$ts, 
+                    prediction = object$pred, 
+                    lpi = object$lower,
+                    upi = object$upper,
+                    level = object$level
+    )
+  }
 }
 
 #' @importFrom graphics plot
 #' @export
-plot.utsf <- function(x, y, ...) {
+plot.utsf_forecast <- function(x, y, ...) {
   timeS <- stats::ts(c(x$ts, x$pred),
                      start = stats::start(x$ts),
                      frequency = stats::frequency(x$ts)
